@@ -23,7 +23,7 @@
 /* #undef WITH_GPROF */
 #define WITH_SIMD
 #define WITH_AVX2
-#define WITH_CUPS
+/* #undef WITH_CUPS */
 #define WITH_JPEG
 /* #undef WITH_WIN8 */
 /* #undef WITH_AAD */
@@ -120,7 +120,7 @@
 #define CHANNEL_PARALLEL_CLIENT
 /* #undef CHANNEL_PARALLEL_SERVER */
 #define CHANNEL_PRINTER
-#define CHANNEL_PRINTER_CLIENT
+/* #undef CHANNEL_PRINTER_CLIENT */
 /* #undef CHANNEL_PRINTER_SERVER */
 #define CHANNEL_RAIL
 #define CHANNEL_RAIL_CLIENT
